/*
 * Copyright(C) OASIS(R) 2006,2009. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */

#ifndef _oasis_sca_SCAException_h_
#define _oasis_sca_SCAException_h_


namespace oasis {
    namespace sca {
            
        /**
         * Defines a root exception type from which all SCA defined exceptions derive.
         */
        class SCAException : public std::exception {
            public:
            
                /**
                 * Returns the name of the exception type.
                 * @return The type of the exception as a string.
                 */
                const char* getEClassName() const;
                
                /**
                 * Returns the text of any message included with the exception
                 * @return The message which the SCA runtime attached to the exception.
                 */
                const char* getMessageText() const;
    
                /**
                 * Returns the filename containing the function where the exception occurred.
                 * @return The filename within which the exception occurred. 
                 *         An empty string if the filename is not known.
                 */
                const char* getFileName() const;
    
                /**
                 * Returns the line number in the source file where the exception occurred.
                 * @return The line number at which the exception occurred.
                 *         0 if the line number is not known.
                 */
                unsigned long getLineNumber() const;
    
                /**
                 * Returns the function name where the exception occurred.
                 * @return The function name in which the exception occurred.
                 *         An empty string if the function name is not known.
                 */
                const char* getFunctionName() const;
        };
        

        /**
          * Signals that code attempted to dereference a null pointer from a RefCountingPointer object.
          */
        class SCANullPointerException : public SCAException {
        };
        
        
        /**
          * Signals problems in the management of the execution of SCA components.
          */
        class ServiceRuntimeException : public SCAException {
        };
        
        
        /**
          * Signals problems in the interaction with remote services.
          */
        class ServiceUnavailablException : public ServiceRuntimeException {
        };
        
        
        /**
          * Signals that a member function expecting identification of a single service
          * is called where there are multiple services defined.
          */
        class MultipleServicesException : public ServiceRuntimeException {
        };
        
    
    } // namespace sca
} // namespace oasis 

#endif /* _oasis_sca_SCAException_h_ */
